==> huaweicloudsdkkoomessage-3.1.58-py2.py3-none-any.whl: huaweicloudsdkkoomessage/v1/model/update_aim_msg_signature_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAimMsgSignatureRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'signature_id': 'str',
        'body': 'SignatureRequest'
    }

    attribute_map = {
        'signature_id': 'signature_id',
        'body': 'body'
    }

    def __init__(self, signature_id=None, body=None):
        """UpdateAimMsgSignatureRequest

        The model defined in huaweicloud sdk

        :param signature_id: 签名ID。
        :type signature_id: str
        :param body: Body of the UpdateAimMsgSignatureRequest
        :type body: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        
        

        self._signature_id = None
        self._body = None
        self.discriminator = None

        self.signature_id = signature_id
        if body is not None:
            self.body = body

    @property
    def signature_id(self):
        """Gets the signature_id of this UpdateAimMsgSignatureRequest.

        签名ID。

        :return: The signature_id of this UpdateAimMsgSignatureRequest.
        :rtype: str
        """
        return self._signature_id

    @signature_id.setter
    def signature_id(self, signature_id):
        """Sets the signature_id of this UpdateAimMsgSignatureRequest.

        签名ID。

        :param signature_id: The signature_id of this UpdateAimMsgSignatureRequest.
        :type signature_id: str
        """
        self._signature_id = signature_id

    @property
    def body(self):
        """Gets the body of this UpdateAimMsgSignatureRequest.

        :return: The body of this UpdateAimMsgSignatureRequest.
        :rtype: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateAimMsgSignatureRequest.

        :param body: The body of this UpdateAimMsgSignatureRequest.
        :type body: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAimMsgSignatureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkkoomessage-3.1.143-py2.py3-none-any.whl: huaweicloudsdkkoomessage/v1/model/update_aim_msg_signature_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateAimMsgSignatureRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'signature_id': 'str',
        'body': 'SignatureRequest'
    }

    attribute_map = {
        'signature_id': 'signature_id',
        'body': 'body'
    }

    def __init__(self, signature_id=None, body=None):
        r"""UpdateAimMsgSignatureRequest

        The model defined in huaweicloud sdk

        :param signature_id: 签名ID。
        :type signature_id: str
        :param body: Body of the UpdateAimMsgSignatureRequest
        :type body: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        
        

        self._signature_id = None
        self._body = None
        self.discriminator = None

        self.signature_id = signature_id
        if body is not None:
            self.body = body

    @property
    def signature_id(self):
        r"""Gets the signature_id of this UpdateAimMsgSignatureRequest.

        签名ID。

        :return: The signature_id of this UpdateAimMsgSignatureRequest.
        :rtype: str
        """
        return self._signature_id

    @signature_id.setter
    def signature_id(self, signature_id):
        r"""Sets the signature_id of this UpdateAimMsgSignatureRequest.

        签名ID。

        :param signature_id: The signature_id of this UpdateAimMsgSignatureRequest.
        :type signature_id: str
        """
        self._signature_id = signature_id

    @property
    def body(self):
        r"""Gets the body of this UpdateAimMsgSignatureRequest.

        :return: The body of this UpdateAimMsgSignatureRequest.
        :rtype: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateAimMsgSignatureRequest.

        :param body: The body of this UpdateAimMsgSignatureRequest.
        :type body: :class:`huaweicloudsdkkoomessage.v1.SignatureRequest`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateAimMsgSignatureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
